@@ -1,5 +1,5 @@
 /* -
- * Copyright (c) 1998-2005 Joao Cabral
+ * Copyright (c) 1998-2008 DHIS, Dynamic Host Information System
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,14 +23,12 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN  IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- *   DHIS(c) Dynamic Host Information System Release 5.3
  *
  */
 
 #include "dhid.h"
 
 int udp_sock;
-extern int rport;
 
 
 /*
@@ -224,7 +222,8 @@ int net_check_message(void) {
  */
 int net_read_message(msg_t *p,int *from) {
 
-	int n,sl;
+	int n;
+	socklen_t sl;
 	struct sockaddr_in sa;
 
         /* Read message */
@@ -246,16 +245,13 @@ int net_read_message(msg_t *p,int *from) {
 int net_write_message(msg_t *p,int toaddr,int toport) {
 
  	struct sockaddr_in sa;
-        int s;
 	int len;
 	int r;
 
 	p->hdr.version=DHIS_VERSION;
 	p->hdr.serial=get_serial();
-	p->hdr.rport=rport;
-	
+
         /* set destination */
-        if((s=socket(AF_INET,SOCK_DGRAM,0))<0) return(0);
         sa.sin_family=AF_INET;
         sa.sin_port=htons(toport);
         sa.sin_addr.s_addr=toaddr;
@@ -267,9 +263,8 @@ int net_write_message(msg_t *p,int toaddr,int toport) {
 	if(little_endian()) convert_message(p,1);
 
         /* Send message request */
-        r=sendto(s,(unsigned char *)p,len,0,(struct sockaddr *)&sa,
+        r=sendto(udp_sock,(unsigned char *)p,len,0,(struct sockaddr *)&sa,
 		sizeof(struct sockaddr_in));
-        close(s);
 
 	/* Convert back just in case */
 	if(little_endian()) convert_message(p,2);
@@ -429,12 +424,12 @@ void qrc_crt(mpz_t x,mpz_t xp,mpz_t xq,mpz_t p,mpz_t q) {
  *		    with n digits of x. Adds 0's to the left if 
  *		    required.
  */
-void qrc_fill_str(mpz_t x,unsigned char *str,int n) {
+void qrc_fill_str(mpz_t x,char *str,int n) {
 	
 	int i,j;
-	unsigned char buff[1024];
-	unsigned char buff2[1024];
-	unsigned char *cp1,*cp2;
+	char buff[1024];
+	char buff2[1024];
+	char *cp1,*cp2;
 
 	i=mpz_sizeinbase(x,10);		/* Get size of x */
 	j=n-i;				/* j = number of 0's to add */
